@@ -15,7 +15,7 @@ var bitsFS embed.FS
 
 func decodeBits(unit int) func(d *decode.D, _ any) any {
 	return func(d *decode.D, _ any) any {
-		var s scalar.S
+		var s scalar.Any
 		b, _ := interp.NewBinaryFromBitReader(d.BitBufRange(0, d.Len()), unit, 0)
 		s.Actual = b
 		d.Value.V = &s
