@@ -35,14 +35,14 @@ func hevcDcrDecode(d *decode.D, _ any) any {
 	d.FieldU6("reserved2")
 	d.FieldU2("chroma_format_idc")
 	d.FieldU5("reserved3")
-	d.FieldU3("bit_depth_luma", scalar.ActualUAdd(8))
+	d.FieldU3("bit_depth_luma", scalar.UintActualAdd(8))
 	d.FieldU5("reserved4")
-	d.FieldU3("bit_depth_chroma", scalar.ActualUAdd(8))
+	d.FieldU3("bit_depth_chroma", scalar.UintActualAdd(8))
 	d.FieldU16("avg_frame_rate")
 	d.FieldU2("constant_frame_rate")
 	d.FieldU3("num_temporal_layers")
 	d.FieldU1("temporal_id_nested")
-	lengthSize := d.FieldU2("length_size", scalar.ActualUAdd(1))
+	lengthSize := d.FieldU2("length_size", scalar.UintActualAdd(1))
 	numArrays := d.FieldU8("num_of_arrays")
 	d.FieldArray("arrays", func(d *decode.D) {
 		for i := uint64(0); i < numArrays; i++ {
